import pandas as pd
import os
from pathlib import Path as pl

def csv(path):
    return pd.read_csv(path)


def fileR(path):
    file = open(path)
    f = file.read()
    return f


def textR(path):
    file = open(path)
    f = file.read()
    return f


def file(path):
    return open(path)


def text(path):
    return open(path)


def excel(path):
    return pd.read_excel(path)


def dataText(p):
    return pd.read_csv(p)


def pd():
    import importlib
    return importlib.import_module("pandas")


def getFilePath(file):
    path = pl(file).parent.absolute()
    return path


def getCfileP():
    p = pl(__file__).parent.absolute()
    return p


def spech():
    print("The function getFilepath() will return the value of the main directory not sub-directory")




import importlib


def HELP():
    print(
        "Your Guide to this part of NEXUS\n",
        "This part of NEXUS will help you import modules in python very easily\n",
        "For example I want to import numpy and pandas\n",
        "The Code: \n",
        "# First import the module part of the nexus module refer to the docs or the github repo for NEXUS\n"
        "np = module.np()\n"
        "#Test it\n"
        "print(np.array([1,2,3,4])\n"

        "For any more help create a stack overflow and send the link in a github issue on the NEXUS repo, OR you can "
        "directly open an issue on the NEXUS repo\n "
        "Hope this helps  :)"
    )


def ipm(md):
    return importlib.import_module(md)


def np():
    return ipm("numpy")


def pd():
    return ipm("pandas")


def sklearn():
    return ipm("sklearn")


def lin_model():
    return ipm("sklearn.linear_model")


def linear_regression():
    return ipm("sklearn.linear_model.LinearRegression")


def torch():
    return ipm("torch")


def tensorflow():
    return ipm("tensorflow")


def pyplot():
    return ipm("matplotlib.pyplot")


def scipy():
    return ipm("scipy")


def selenium():
    return ipm("selenium")


def opencv():
    return ipm("cv2")


def bs4():
    return ipm("bs4")


def module(md):
    return ipm(md)


def random():
    return ipm("random")


def math():
    return ipm("math")


def os():
    return ipm("os")


def sys():
    return ipm("sys")


def socket():
    return ipm("sockets")


def pickle():
    return ipm(
        "pickle"
    )


def time():
    return ipm("time")


def dtime():
    return ipm("datetime")


def cgi():
    return ipm("cgi")


def re():
    return ipm("re")


def ulib():
    return ipm("urllib")


def ulib3():
    return ipm("urllib3")




import glob as g
import pyttsx3 as pt
from win32com.client import Dispatch as dis
from gtts import gTTS as gt
from playsound import playsound as ps

def skp1(txt):
    engine = pt.init()
    engine.say(txt)
    engine.runAndWait()

def spk2(tr):
    a = dis("SAPI.SpVoice").Speak
    a(str(tr))


def spk_mp3(Text, name):
    val = gt(text=Text, lang='en')
    val.save(name)
    ps(name)


def playSound(flnme):
    ps(flnme)
    
def advance_speak(TEXT, lang, file_name, slowness, play):
    sod = gt(text=TEXT, lang=lang, slow=slowness)
    sod.save(file_name)

    if play:
          ps(file_name)

def check_mp3():
    lisT = []
    for i in g.glob("*.mp3"):
          lisT.append(i)
    return lisT


def check_file(typE):
    lop = []
    for i in g.glob(typE):
          lop.append(i)

    return lop




import random # It will take time I guess
import webbrowser as wb
from kivy.app import App
from kivy.uix.label import Label
from kivy.uix.gridlayout import GridLayout
from kivy.uix.textinput import TextInput
from kivy.uix.button import Button

wb.register(
    'cr',
    None,
    wb.BackgroundBrowser('C:\Program Files (x86)\Google\Chrome\Application\chrome.exe') # Got my chrome path

)

class Lay(GridLayout): # Grid not Gird
    def __init__(self, **kwargs):
        super().__init__(**kwargs)

        self.rows = 2
        self.cols = 1
        Button.background_color = 1.2, 0.34, 1, 0.8

        self.inp = TextInput(multiline=True)
        self.add_widget(self.inp)

        self.src = Button(text="Search The Web", font_size=45)
        self.src.bind(on_press=self.pressed)
        self.add_widget(self.src)
        # self.add_widget(Label(text="test for Grid Layout"))  # I am gonna make this short\

    def pressed(self, instance):
        wb.get('cr').open(self.inp.text)

    # Now  I will test my own website I made yesterday
    # Happy new Year





class WebCrawler(App):
    def build(self):
        a = Lay()
        return a



WebCrawler().run()



def NOT(a):
    if a == 0:
        print(bool(1))
    elif a == 1:
        print(bool(0))
    else:
        print("This type is not in the database")


def AND(a, b):
    if a == 1 and b == 1:
        print(bool(1))
    else:
        print(bool(0))


def OR(a, b):
    if a == 0 and b == 0:
        print(bool(0))
    else:
        print(bool(1))


# Nor gate is when we first use an or gate then use that output for a NOT gate
def NOR(a, b):
    if a == 0 and b == 0:

        print(bool(1))
    else:
        print(bool(0))


def NAND(a, b):
    if a == 1 and b == 1:
        print(bool(0))
    else:
        print(bool(1))


# AND   |   OR   |   NOT  |   NOR

# To convert bin to int
def bint(n):
    print(int(n))


#  To convert int to bin

def dbin(n):
    print(bin(n))

def XNOR(a, b):
    if a == 0 and b == 0 or a == 1 and b == 1:
        print(bool(1))
    else:
        print(bool(0))

def XOR(a, b):
    if a == 1 and b == 1:
        return bool(0)
    elif a == 0 and b == 0:
        print(bool(0))
    else:
        print(bool(1))


XOR(0, 0)


import setuptools as set
from setuptools import find_packages

set.setup(
    name = "testfoRnExuDSA",
    version = "1.0.0",
    author = "Saad-py",
    author_email = "saadyarkhan11@gmail.com",
    description="Neux, a package intended to make all of the python users life easier ",
    long_description="Howdie Programmers,\nNeux is the library to help you make your python life easier.\n\nNeed Help?\n\nIf you are an experienced programmer You guys know you can use help() function in python\nIf you are a beginner be sure to keep checking the Github repo for Neux and I may upload YouTube videos explaining how Neux works\nThe docs will be released after the third major update because all the important things will be added by then.\n\n\nIssues: \nWant to talk create an issue on github or send an email to the given email located somewhere in the repo.\nCan't Find Email, Here it is: saadyarkhan11@gmail.com\nI am on Hangouts, but not Discord.\nThanks for Downloading",
    packages=find_packages(),
)




import random
import webbrowser as wb
# raise ValueError('A very specific bad thing happened.')

def add(a, b):

    if a != int or b != int:
        print()
        print()
        raise ValueError("Values should be int not str")
    # print("Result: ")
    elif a != str and b != str:
        return a + b

def product(a, b):
    if a != int or b != int:
        print()
        print()
        raise ValueError("Values should be int not str")
    # print("Result: ")
    elif a != str and b != str:
        return a * b

def div(a, b):
    if a != int or b != int:
        print()
        print()
        raise ValueError("Values should be int not str")
    # print("Result: ")
    elif a != str and b != str:
        return a / b

def subt(a, b):
    if a != int or b != int:
        print()
        print()
        raise ValueError("Values should be int not str")
    # print("Result: ")
    elif a != str and b != str:
        return a - b

def fraction_decimal(e, f):
    divi(e, f)

def decimal_percentage(g):
    g = float(g)
    g = g * 100
    g = g,'%'
    return g

def to_the_power(h, i):
    return h ^ i

def gen_float(j):
    p1 = random.random(0, 1)
    return j + p1

def randm(k, l):
    rand = random.ranint(k, l)
    return rand

def KO_num(m):
    m += random.random(0, 34.324238240)
    return m

def make0(n):
	n = 0
	return n

def chr_path(path):
    wb.register(
        'Chrome',
        None,
        wb.BackgroundBrowser(path)
    )

def open_calc():
    try:
        wb.get("Chrome").open('https://www.google.com/search?safe=strict&rlz=1C1CHBD_enAE775AE775&sxsrf=ALeKk03LglonBbvv6Xx5Qg1XLG66Hr70ug%3A1609823996210&ei=_PbzX6OpDIqbgQaV8JqgCQ&q=calc&oq=calc&gs_lcp=CgZwc3ktYWIQA1A0WPECYLoEaABwAXgAgAEAiAEAkgEAmAEAoAEBqgEHZ3dzLXdpesABAQ&sclient=psy-ab&ved=0ahUKEwijl8fbhYTuAhWKTcAKHRW4BpQQ4dUDCA0&uact=5')
    except Exception:
        wb.open('https://www.google.com/search?safe=strict&rlz=1C1CHBD_enAE775AE775&sxsrf=ALeKk03LglonBbvv6Xx5Qg1XLG66Hr70ug%3A1609823996210&ei=_PbzX6OpDIqbgQaV8JqgCQ&q=calc&oq=calc&gs_lcp=CgZwc3ktYWIQA1A0WPECYLoEaABwAXgAgAEAiAEAkgEAmAEAoAEBqgEHZ3dzLXdpesABAQ&sclient=psy-ab&ved=0ahUKEwijl8fbhYTuAhWKTcAKHRW4BpQQ4dUDCA0&uact=5')


def help_the_dev():
    print("Follow my GitHub: github.com/Saad-py")
    print("Thanks for using this function")

def greater_than(a, b):
    if a > b:
        return True

def less_than(a, b):
    if a < b:
        return True
        
def equal_to(a, b):
    if a == b:
        return True
    else:
        return False   


def check_the_nums(num1, num2):
    if num1 > num2:
        print(num1, 'is Greater')
    elif num2 > num1:
        print(num2, 'is Greater')
    elif num1 == num2:
        print('They are Same')

def qt():
	quit()



# 40 or 41 funcctions are done Hundreds more to go
